[][src]Struct pai_gst_sequencer::PAISequencer

pub struct PAISequencer { /* fields omitted */ }

Periscopai sequence pipeline

Arguments

Implementations

impl PAISequencer[src]

pub const CREATED: u8[src]

pub const ERROR: u8[src]

pub const RUNNING: u8[src]

pub const STOPPED: u8[src]

pub fn new(input: &str) -> PAISequencer[src]

pub fn start(&mut self) -> u8[src]

starts the sequencer and sets the state to RUNNING

Returns:PAISequencerState::RUNNING

Note that the reference to self is set as mutable as we want to be able to change the state.

pub fn stop(&mut self) -> u8[src]

pub fn state(&self) -> u8[src]

pub fn input(&self) -> &String[src]